@@ -50,16 +50,18 @@ class IconWidget(Widget, Control):
     :param int anchored_position: (x,y) pixel value for the location of the anchor_point
     :type anchored_position: Tuple[int, int]
     :param int max_size: (Optional) this will get passed through to the
-     displayio.Group constructor. If omitted we default to
-     grid_size width * grid_size height to make room for all (1, 1) sized cells.
+     displayio.Group constructor. ``max_size`` should be set to the maximum number of
+     graphical elements that will be held within the Group of this widget.
 
     """
 
     def __init__(self, label_text, icon, on_disk=False, **kwargs):
         super().__init__(**kwargs)
 
+        self._icon = icon
+
         if on_disk:
-            self._file = open(icon, "rb")
+            self._file = open(self._icon, "rb")
             image = OnDiskBitmap(self._file)
             tile_grid = TileGrid(image, pixel_shader=ColorConverter())
         else:
